@@ -28,7 +28,7 @@ VolumeMeterWidget::VolumeMeterWidget(QWidget *parent) :
     currentValue = 0;
 }
 
-void VolumeMeterWidget::paintEvent(QPaintEvent *event){
+void VolumeMeterWidget::paintEvent(QPaintEvent */*event*/){
     QPainter painter(this);
     painter.setRenderHint(QPainter::Antialiasing, true);
 
@@ -50,34 +50,64 @@ void VolumeMeterWidget::draw(QPainter *painter){
     thickPen.setWidth(4);
 
     painter->setPen(thinPen);
-    painter->drawText(-20, -270, 40, 20, Qt::AlignCenter, "dB");
+    QString label = (dbUnit) ? "dB" : "Linear";
+    painter->drawText(-40, -270, 80, 20, Qt::AlignCenter, label);
 
     painter->rotate(-25);
-    for(int i = 0; i < 23; i++){
-        if(i % 4 == 0){
-            if(i >= 16){
-                thickPen.setColor(Qt::red);
-            }
 
-            painter->setPen(thickPen);
-            painter->drawLine(0, -297, 0, -315);
-            painter->drawText(-20, -340, 40, 20, Qt::AlignCenter, QString().setNum((i/4)*20));
-        }else{
-            if(i >= 16){
-                thinPen.setColor(Qt::red);
-            }
-            painter->setPen(thinPen);
+    if(dbUnit){
+        for(int i = 0; i < 23; i++){
+            if(i % 4 == 0){
+                if(i >= 16){
+                    thickPen.setColor(Qt::red);
+                }
 
-            if(i % 2 == 0){
-                painter->drawLine(0, -296, 0, -308);
+                painter->setPen(thickPen);
+                painter->drawLine(0, -297, 0, -315);
+                painter->drawText(-20, -340, 40, 20, Qt::AlignCenter, QString().setNum((i/4)*20));
             }else{
-                painter->drawLine(0, -296, 0, -303);
-            }
-        }
+                if(i >= 16){
+                    thinPen.setColor(Qt::red);
+                }
+                painter->setPen(thinPen);
 
-        painter->rotate(50./110.*5.);
+                if(i % 2 == 0){
+                    painter->drawLine(0, -296, 0, -308);
+                }else{
+                    painter->drawLine(0, -296, 0, -303);
+                }
+            }
+
+            painter->rotate(50./110.*5.);
+        }
+        painter->rotate(-50./110.*5.);
+    }else{
+        for(int i = 0; i < 17; i++){
+            if(i % 4 == 0){
+                if(i >= 12){
+                    thickPen.setColor(Qt::red);
+                }
+
+                painter->setPen(thickPen);
+                painter->drawLine(0, -297, 0, -315);
+                painter->drawText(-20, -335, 40, 20, Qt::AlignCenter, QString().setNum((i/4)*50));
+            }else{
+                if(i >= 12){
+                    thinPen.setColor(Qt::red);
+                }
+                painter->setPen(thinPen);
+
+                if(i % 2 == 0){
+                    painter->drawLine(0, -296, 0, -308);
+                }else{
+                    painter->drawLine(0, -296, 0, -303);
+                }
+            }
+
+            painter->rotate(50./200.*12.5);
+        }
+        painter->rotate(-50./200.*12.5);
     }
-    painter->rotate(-50./110.*5.);
 
     painter->rotate(-25);
     thinPen.setColor(Qt::black);
@@ -85,12 +115,23 @@ void VolumeMeterWidget::draw(QPainter *painter){
     painter->drawArc(-160, -295, 320, 150, 35*16, 110*16);
 
     painter->rotate(-25);
-    painter->rotate(50./110. * currentValue);
+
+    if(dbUnit){
+        painter->rotate(50./110. * currentValue);
+    }else{
+        painter->rotate(50./200. * currentValue);
+    }
     thinPen.setColor(Qt::red);
     painter->setPen(thinPen);
     painter->drawLine(0, 0, 0, -325);
 }
 
+void VolumeMeterWidget::setDbUnit(bool b){
+    dbUnit = b;
+    currentValue = 0;
+    update();
+}
+
 void VolumeMeterWidget::updateValue(int value){
     currentValue = value;
     emit update();
